@@ -1,12 +1,14 @@
-import json
+import ujson
 
 class connect:
     def __init__(self, name="index", *, path=""):
-        """ Creates the index.json file if it doesn't exist, or opens an existing one.
+        """ Creates the file if it doesn't exist, or opens an existing one.
 
             Arguments:
                 name -- type: str (default: "index"),
                 path -- type: str (default: "")
+
+            Return: class
         """
         self.name = name
         self.path = path
@@ -21,21 +23,23 @@ class connect:
             w = open(f"{self.path}/{self.name}.json", "w+").write("{}")
             r = open(f"{self.path}/{self.name}.json", "r").read()
 
-        self.database = json.loads(r)
+        self.database = ujson.loads(r)
 
 
     def get(self, *, printf=False):
-        """ Returns the database dictionary.
+        """ Returns the self.database dictionary.
 
             Arguments:
                 printf -- type: bool (default: False)
+
+            Return: dict
         """
         if printf: print(self.database)
         return self.database
 
     def save(self):
         """ Saves the database dictionary to a file. """
-        return json.dump(self.database, open(f"{self.path}/{self.name}.json", "w+"), indent=4)
+        return ujson.dump(self.database, open(f"{self.path}/{self.name}.json", "w+"), indent=4)
 
     def get_item(self, key, *, printf=False):
         """ Returns the key value.
@@ -43,6 +47,8 @@ class connect:
             Arguments:
                 key -- type: str or list
                 printf -- type: bool (default: False)
+
+            Return: all type
         """
         if type(key) is str:
             if printf: print(self.database[key])
@@ -60,6 +66,8 @@ class connect:
             Arguments:
                 key -- type: str or list
                 value -- type: all
+
+            Return: None
         """
         if type(key) is str:
             self.database[key] = value
@@ -76,6 +84,8 @@ class connect:
 
             Arguments:
                 key -- type: str or list
+
+            Return: None
         """
         if type(key) is str:
             del self.database[key]
@@ -90,6 +100,8 @@ class connect:
 
             Arguments:
                 key -- type: str
+
+            Return: list
         """
         result = []
         for i in self.cache:
@@ -101,8 +113,9 @@ class connect:
         """ Returns a list of cache.
 
             Arguments:
+                printf -- type: bool (default: False)
 
-            printf -- type: bool (default: False)
+            Return: list
         """
         if printf: print(self.cache)
         return self.cache
